OiRA

Help

1. Priprava
2. Vključevanje
3. Identifikacija + Ocena
   1. 1 Commercial manned guarding
   2. Ω Vaša dodana tveganja
      1. Ω.1 The entrance floor is often wet
   - Neodgovorjeno
   - Preloženo
   - Urejeno
   - Neurejeno
4. Načrt ukrepov
5. Poročilo
6. Status 0%

Če ste opredelili tveganja, ki niso vključena v orodje, jih lahko dodate zdaj:

Pomembno: Da bi se izognili podvajanju tveganj, vam zelo priporočamo, da najprej pregledate vse prejšnje module, če tega še niste storili.

Če ni treba dodati tveganj, nadaljujte.

Nazaj Nadaljuj na načrt ukrepov

Scroll to top
Back

## other-risks.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More